obelisk.sync.consumer\_test
===========================

.. automodule:: obelisk.sync.consumer_test

   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      test_demo_igent
      test_two_instances
   